==> seedsui-react-5.6.26.tgz: package/lib/TreePicker/Tree/Utils.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

export default {
  // 获取选中项
  getCheckedKeysProp: function getCheckedKeysProp(value, defaultValue) {
    var val = value || defaultValue;
    var checkedKeys = [];

    if (Array.isArray(val) && val.length) {
      var _iterator = _createForOfIteratorHelper(val),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var item = _step.value;

          if (item.id) {
            checkedKeys.push(item.id);
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    } // value or defaultValue


    var valueProp = {};

    if (value) {
      valueProp = {
        checkedKeys: checkedKeys
      };
    } else if (defaultValue) {
      valueProp = {
        defaultCheckedKeys: checkedKeys
      };
    }

    return valueProp;
  },
  // 构建渲染数据, 支持关键字搜索
  getTreeData: function getTreeData(originData, keyword) {
    if (!originData) return originData; // 关键字搜索

    var loop = function loop(data) {
      return data.map(function (item) {
        var name = item.name;
        var index = name.indexOf(keyword);
        var beforeStr = name.substring(0, index);
        var afterStr = name.slice(index + keyword.length);
        var titleDOM = index > -1 ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
          className: "treepicker-keyword-highlight-before"
        }, beforeStr), /*#__PURE__*/React.createElement("span", {
          className: "treepicker-keyword-highlight-text"
        }, keyword), /*#__PURE__*/React.createElement("span", {
          className: "treepicker-keyword-highlight-before"
        }, afterStr)) : name;

        if (item.children) {
          return {
            title: titleDOM,
            name: name,
            id: item.id,
            children: loop(item.children)
          };
        }

        return {
          title: titleDOM,
          name: name,
          id: item.id
        };
      });
    };

    return loop(originData);
  },
  // 名称匹配拼音, 返回匹配到的汉字
  getKeywordIdsByPinyin: function getKeywordIdsByPinyin(keyword, name) {
    var _name$toPinyin;

    if (!name || typeof name !== 'string') return '';
    if (!keyword) return name;
    var pinyinIndex = name === null || name === void 0 ? void 0 : (_name$toPinyin = name.toPinyin()) === null || _name$toPinyin === void 0 ? void 0 : _name$toPinyin.indexOf(keyword.toLowerCase());

    if (pinyinIndex !== -1) {
      return name;
    }

    return '';
  },
  // 获取关键字的所有匹配的keys
  getKeywordIds: function getKeywordIds(keyword, flattenTree) {
    if (!keyword || typeof keyword !== 'string') return [];
    var keys = [];

    var _iterator2 = _createForOfIteratorHelper(flattenTree),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var node = _step2.value;

        if (node.name && node.name.indexOf(keyword) !== -1) {
          keys.push(node.id);
        }
      } // 如果没有匹配到, 再根据拼音匹配

      /*
      if (keys.length < 1 && keyword && /^[a-zA-Z]+$/.test(keyword)) {
        for (let item of flattenTree) {
          if (this.getKeywordIdsByPinyin(keyword, item.name)) {
            keys.push(item.id)
            break
          }
        }
      }
      */

    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }

    return keys;
  },
  // 根据id获取你级的id
  getExpandedKeys: function getExpandedKeys(keyword, flattenTree) {
    // 获取所有选中项
    var ids = this.getKeywordIds(keyword, flattenTree); // 获取所有选中项的所有的父级

    var expandedKeys = [];

    var _iterator3 = _createForOfIteratorHelper(ids),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var id = _step3.value;
        var parentId = flattenTree.getFlattenTreeNode(id).parentid;
        var predecessors = flattenTree.getFlattenTreePredecessors(parentId);

        var _iterator4 = _createForOfIteratorHelper(predecessors),
            _step4;

        try {
          for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
            var node = _step4.value;

            if (expandedKeys.indexOf(node.id) === -1) {
              expandedKeys.push(node.id);
            }
          }
        } catch (err) {
          _iterator4.e(err);
        } finally {
          _iterator4.f();
        }
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }

    return expandedKeys;
  }
};

==> seedsui-react-5.6.29.tgz: package/lib/TreePicker/Tree/Utils.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

import HighlightKeyword from "./../../HighlightKeyword";
export default {
  // 获取选中项
  getCheckedKeysProp: function getCheckedKeysProp(value, defaultValue) {
    var val = value || defaultValue;
    var checkedKeys = [];

    if (Array.isArray(val) && val.length) {
      var _iterator = _createForOfIteratorHelper(val),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var item = _step.value;

          if (item.id) {
            checkedKeys.push(item.id);
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    } // value or defaultValue


    var valueProp = {};

    if (value) {
      valueProp = {
        checkedKeys: checkedKeys
      };
    } else if (defaultValue) {
      valueProp = {
        defaultCheckedKeys: checkedKeys
      };
    }

    return valueProp;
  },
  // 构建渲染数据, 支持关键字搜索
  getTreeData: function getTreeData(originData, keyword) {
    if (!originData) return originData; // 关键字搜索

    var loop = function loop(data) {
      return data.map(function (item) {
        var name = item.name;
        var titleDOM = /*#__PURE__*/React.createElement(HighlightKeyword, {
          text: name,
          keyword: keyword
        });

        if (item.children) {
          return {
            title: titleDOM,
            name: name,
            id: item.id,
            children: loop(item.children)
          };
        }

        return {
          title: titleDOM,
          name: name,
          id: item.id
        };
      });
    };

    return loop(originData);
  },
  // 名称匹配拼音, 返回匹配到的汉字
  getKeywordIdsByPinyin: function getKeywordIdsByPinyin(keyword, name) {
    var _name$toPinyin;

    if (!name || typeof name !== 'string') return '';
    if (!keyword) return name;
    var pinyinIndex = name === null || name === void 0 ? void 0 : (_name$toPinyin = name.toPinyin()) === null || _name$toPinyin === void 0 ? void 0 : _name$toPinyin.indexOf(keyword.toLowerCase());

    if (pinyinIndex !== -1) {
      return name;
    }

    return '';
  },
  // 获取关键字的所有匹配的keys
  getKeywordIds: function getKeywordIds(keyword, flattenTree) {
    if (!keyword || typeof keyword !== 'string') return [];
    var keys = [];

    var _iterator2 = _createForOfIteratorHelper(flattenTree),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var node = _step2.value;

        if (node.name && node.name.indexOf(keyword) !== -1) {
          keys.push(node.id);
        }
      } // 如果没有匹配到, 再根据拼音匹配

      /*
      if (keys.length < 1 && keyword && /^[a-zA-Z]+$/.test(keyword)) {
        for (let item of flattenTree) {
          if (this.getKeywordIdsByPinyin(keyword, item.name)) {
            keys.push(item.id)
            break
          }
        }
      }
      */

    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }

    return keys;
  },
  // 根据id获取你级的id
  getExpandedKeys: function getExpandedKeys(keyword, flattenTree) {
    // 获取所有选中项
    var ids = this.getKeywordIds(keyword, flattenTree); // 获取所有选中项的所有的父级

    var expandedKeys = [];

    var _iterator3 = _createForOfIteratorHelper(ids),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var id = _step3.value;
        var parentId = flattenTree.getFlattenTreeNode(id).parentid;
        var predecessors = flattenTree.getFlattenTreePredecessors(parentId);

        var _iterator4 = _createForOfIteratorHelper(predecessors),
            _step4;

        try {
          for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
            var node = _step4.value;

            if (expandedKeys.indexOf(node.id) === -1) {
              expandedKeys.push(node.id);
            }
          }
        } catch (err) {
          _iterator4.e(err);
        } finally {
          _iterator4.f();
        }
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }

    return expandedKeys;
  }
};
